@@ -85,3 +85,11 @@ The filename (relative to the base directory unless it's absolute) for
 storing cached reference values using the `shelve` module.
 TODO: Use this!
 """
+
+LOCALE = "en_US.utf-8"
+"""
+The locale to set when `potluck.control.setup` is called. Most
+importantly, this affects the default encoding used by open() calls, in
+both solution and submitted code. This value is set as the LC_ALL value
+using `locale.setlocale`.
+"""
