@@ -1926,14 +1926,16 @@ def returns_a_new_value(target, *args, **kwargs):
         if argindex < len(args):
             # a positional argument
             argval = args[argindex]
+            argref = phrasing.ordinal(argindex)
         else:
             # a keyword argument (possibly defaulted via omission)
             argval = kwargs.get(argname, target.__kwdefaults__[argname])
+            argref = repr(argname)
 
         if fresult is argval:
             return (
-                "Returned the '{}' argument (possibly with modifications)."
-            ).format(argname)
+                "Returned the {} argument (possibly with modifications)."
+            ).format(argref)
 
     # Since we didn't return in the loop above, there's no match
     return "Returned a new value."
