@@ -311,6 +311,124 @@ window.addEventListener("load", function () {
 });
 
 
+/* Gets the goal type (as a string) from a rubric row node, returning
+ * the string 'none' if it doesn't have one).
+ */
+function get_goal_type(rubric_row_node) {
+    for (let cls of rubric_row_node.classList) {
+        if (cls.startsWith("tag-goal_type-")) {
+            return cls.slice(14);
+        }
+    }
+    return 'none';
+}
+
+/* Like get_goal_type but for the goal category. */
+function get_goal_category(rubric_row_node) {
+    for (let cls of rubric_row_node.classList) {
+        if (cls.startsWith("tag-category-")) {
+            return cls.slice(13);
+        }
+    }
+    return 'none';
+}
+
+/* Gets the function associated with a rubric row, actually just based on
+ * the first 'code' tag in the goal-topic span. Returns '(no function)'
+ * for rows that don't have a code tag in their goal topic.
+ */
+function get_goal_function(rubric_row_node) {
+    topic_node = rubric_row_node.querySelector(".goal-topic");
+    if (topic_node == null) { return '(no function)'; }
+    code = topic_node.querySelector('code');
+    if (code == null) { return '(no function)'; }
+    return code.outerHTML;
+}
+
+/*
+ * Re-organizes goals according to different grouping policies. Valid
+ * sorting policies are: "category", "type", and "function", with
+ * "category" being the default.
+ */
+function reorganize_goals(grouping_policy) {
+    if (grouping_policy == undefined) { grouping_policy = "category"; }
+
+    // Find all top-level goal rows: things that aren't categories but
+    // which are inside a category, or with are at the top level of the
+    // rubric table and aren't categories:
+    let goal_rows = [...document.querySelectorAll(
+        ".rubric_row.goal_category>.rubric_table"
+      + ">.rubric_row:not(.goal_category)"
+    )].concat([...document.querySelectorAll(
+        ":not(.rubric_row)>.rubric_table>.rubric_row:not(.goal_category)"
+    )]);
+    let grouper = get_goal_category;
+    if (grouping_policy == "type") {
+        grouper = get_goal_type;
+    } else if (grouping_policy == "function") {
+        grouper = get_goal_function;
+    } else if (grouping_policy == "category") {
+        grouper = get_goal_category;
+    } else {
+        console.warn(
+            "Invalid sorting policy '" + grouping_policy
+          + "': using 'category' by default."
+        );
+        grouper = get_goal_category;
+    }
+
+    // Group rows according to the grouping function
+    let group_titles = [];
+    let groups = [];
+    for (let row of goal_rows) {
+        let group = grouper(row);
+        let index = group_titles.indexOf(group);
+        if (index == -1) {
+            group_titles.push(group);
+            groups.push([row]);
+        } else {
+            groups[index].push(row);
+        }
+    }
+
+    // Replace table with grouped rows
+    let toplevel = document.querySelector(":not(.rubric_row)>.rubric_table");
+
+    // Create replacement table
+    let replacement = document.createElement('div');
+    replacement.classList.add("rubric_table");
+
+    // Group things up
+    for (let i = 0; i < group_titles.length; ++i) {
+        replacement.innerHTML += (
+            "<h3 class='rubric_group_tile'>" + group_titles[i] + "</h3>"
+        );
+        for (let row of groups[i]) {
+            replacement.innerHTML += row.outerHTML;
+        }
+    }
+
+    // Swap out content
+    toplevel.innerHTML = replacement.innerHTML;
+}
+
+// Reorganize goals on load + on selector change if there is one
+window.addEventListener("load", function () {
+    let grouping_policy_selector = document.getElementById(
+        "grouping_policy"
+    );
+    if (grouping_policy_selector == null) {
+        grouping_policy = "category";
+    } else {
+        grouping_policy = grouping_policy_selector.value;
+        grouping_policy_selector.addEventListener("change", function () {
+            reorganize_goals(this.value);
+        });
+    }
+    reorganize_goals(grouping_policy);
+});
+
+
 /*-------------*
  * Sticky bins *
  *-------------*/
