@@ -34,9 +34,9 @@ gr2.refine(spec.DistinctionReport).goal("extra")
 # Require docstrings
 spec.RequireDocstrings()
 
-# Check that tests are established and pass
-spec.RequireExpectations({"whatever": 3})
-spec.ObserveExpectationResults()
+# Note: can't check expectations/tests because results aren't
+# well-defined. TODO: Some way to check student tests against student
+# code only...
 
 # Construct our rubric
 rubric = spec.rubric()
@@ -53,8 +53,6 @@ meta.example("imperfect")
 meta.expect("partial", "process", "core", "must not crash")
 meta.expect("failed", "product", "core", "distinctions")
 meta.expect("failed", "product", "extra", "distinctions")
-meta.expect("partial", "testing", "core", "defines")
-meta.expect("partial", "testing", "extra", "were met")
 
 
 # This submission runs crashing code in a test T_T
@@ -64,5 +62,3 @@ meta.expect("failed", "style", "core", "documented")
 meta.expect("failed", "process", "core", "must not crash")
 meta.expect("failed", "product", "core", "distinctions")
 meta.expect("failed", "product", "extra", "distinctions")
-meta.expect("failed", "testing", "core", "defines")
-meta.expect("failed", "testing", "extra", "were met")
